@@ -49,6 +49,9 @@ oFFSET_StgRegTable_rHpAlloc = 184
 oFFSET_StgRegTable_rRet :: Int
 oFFSET_StgRegTable_rRet = 192
 #define StgRegTable_rRet(__ptr__)  REP_StgRegTable_rRet[__ptr__+OFFSET_StgRegTable_rRet]
+oFFSET_StgRegTable_rNursery :: Int
+oFFSET_StgRegTable_rNursery = 160
+#define StgRegTable_rNursery(__ptr__)  REP_StgRegTable_rNursery[__ptr__+OFFSET_StgRegTable_rNursery]
 oFFSET_stgEagerBlackholeInfo :: Int
 oFFSET_stgEagerBlackholeInfo = 18446744073709551592
 oFFSET_stgGCEnter1 :: Int
@@ -58,13 +61,16 @@ oFFSET_stgGCFun = 18446744073709551608
 oFFSET_Capability_r :: Int
 oFFSET_Capability_r = 24
 oFFSET_Capability_lock :: Int
-oFFSET_Capability_lock = 304
+oFFSET_Capability_lock = 312
 oFFSET_Capability_mut_lists :: Int
 oFFSET_Capability_mut_lists = 272
 #define Capability_mut_lists(__ptr__)  REP_Capability_mut_lists[__ptr__+OFFSET_Capability_mut_lists]
 oFFSET_Capability_context_switch :: Int
-oFFSET_Capability_context_switch = 288
+oFFSET_Capability_context_switch = 296
 #define Capability_context_switch(__ptr__)  REP_Capability_context_switch[__ptr__+OFFSET_Capability_context_switch]
+oFFSET_Capability_sparks :: Int
+oFFSET_Capability_sparks = 344
+#define Capability_sparks(__ptr__)  REP_Capability_sparks[__ptr__+OFFSET_Capability_sparks]
 oFFSET_bdescr_start :: Int
 oFFSET_bdescr_start = 0
 #define bdescr_start(__ptr__)  REP_bdescr_start[__ptr__+OFFSET_bdescr_start]
@@ -75,16 +81,19 @@ oFFSET_bdescr_blocks :: Int
 oFFSET_bdescr_blocks = 48
 #define bdescr_blocks(__ptr__)  REP_bdescr_blocks[__ptr__+OFFSET_bdescr_blocks]
 oFFSET_bdescr_gen_no :: Int
-oFFSET_bdescr_gen_no = 32
+oFFSET_bdescr_gen_no = 52
 #define bdescr_gen_no(__ptr__)  REP_bdescr_gen_no[__ptr__+OFFSET_bdescr_gen_no]
 oFFSET_bdescr_link :: Int
 oFFSET_bdescr_link = 16
 #define bdescr_link(__ptr__)  REP_bdescr_link[__ptr__+OFFSET_bdescr_link]
 sIZEOF_generation :: Int
-sIZEOF_generation = 56
+sIZEOF_generation = 336
 oFFSET_generation_mut_list :: Int
-oFFSET_generation_mut_list = 24
+oFFSET_generation_mut_list = 64
 #define generation_mut_list(__ptr__)  REP_generation_mut_list[__ptr__+OFFSET_generation_mut_list]
+oFFSET_generation_n_new_large_blocks :: Int
+oFFSET_generation_n_new_large_blocks = 48
+#define generation_n_new_large_blocks(__ptr__)  REP_generation_n_new_large_blocks[__ptr__+OFFSET_generation_n_new_large_blocks]
 sIZEOF_CostCentreStack :: Int
 sIZEOF_CostCentreStack = 88
 oFFSET_CostCentreStack_ccsID :: Int
@@ -147,9 +156,9 @@ oFFSET_StgMutArrPtrs_size = 8
 #define StgMutArrPtrs_size(__ptr__)  REP_StgMutArrPtrs_size[__ptr__+SIZEOF_StgHeader+OFFSET_StgMutArrPtrs_size]
 sIZEOF_StgArrWords_NoHdr :: Int
 sIZEOF_StgArrWords_NoHdr = 8
-oFFSET_StgArrWords_words :: Int
-oFFSET_StgArrWords_words = 0
-#define StgArrWords_words(__ptr__)  REP_StgArrWords_words[__ptr__+SIZEOF_StgHeader+OFFSET_StgArrWords_words]
+oFFSET_StgArrWords_bytes :: Int
+oFFSET_StgArrWords_bytes = 0
+#define StgArrWords_bytes(__ptr__)  REP_StgArrWords_bytes[__ptr__+SIZEOF_StgHeader+OFFSET_StgArrWords_bytes]
 oFFSET_StgArrWords_payload :: Int
 oFFSET_StgArrWords_payload = 8
 #define StgArrWords_payload(__ptr__,__ix__)  W_[__ptr__+SIZEOF_StgHeader+OFFSET_StgArrWords_payload + WDS(__ix__)]
@@ -189,18 +198,21 @@ oFFSET_StgTSO_flags = 28
 oFFSET_StgTSO_dirty :: Int
 oFFSET_StgTSO_dirty = 16
 #define StgTSO_dirty(__ptr__)  REP_StgTSO_dirty[__ptr__+SIZEOF_StgHeader+OFFSET_StgTSO_dirty]
+oFFSET_StgTSO_bq :: Int
+oFFSET_StgTSO_bq = 80
+#define StgTSO_bq(__ptr__)  REP_StgTSO_bq[__ptr__+SIZEOF_StgHeader+OFFSET_StgTSO_bq]
 oFFSET_StgTSO_CCCS :: Int
-oFFSET_StgTSO_CCCS = 80
+oFFSET_StgTSO_CCCS = 88
 #define StgTSO_CCCS(__ptr__)  REP_StgTSO_CCCS[__ptr__+SIZEOF_StgHeader+OFFSET_StgTSO_CCCS]
 oFFSET_StgTSO_sp :: Int
-oFFSET_StgTSO_sp = 88
+oFFSET_StgTSO_sp = 96
 #define TSO_OFFSET_StgTSO_sp (SIZEOF_StgHeader+SIZEOF_OPT_StgTSOProfInfo+OFFSET_StgTSO_sp)
 #define StgTSO_sp(__ptr__)  REP_StgTSO_sp[__ptr__+TSO_OFFSET_StgTSO_sp]
 oFFSET_StgTSO_stack :: Int
-oFFSET_StgTSO_stack = 96
+oFFSET_StgTSO_stack = 104
 #define TSO_OFFSET_StgTSO_stack (SIZEOF_StgHeader+SIZEOF_OPT_StgTSOProfInfo+OFFSET_StgTSO_stack)
 oFFSET_StgTSO_stack_size :: Int
-oFFSET_StgTSO_stack_size = 80
+oFFSET_StgTSO_stack_size = 88
 #define TSO_OFFSET_StgTSO_stack_size (SIZEOF_StgHeader+SIZEOF_OPT_StgTSOProfInfo+OFFSET_StgTSO_stack_size)
 #define StgTSO_stack_size(__ptr__)  REP_StgTSO_stack_size[__ptr__+TSO_OFFSET_StgTSO_stack_size]
 sIZEOF_StgTSOProfInfo :: Int
@@ -296,7 +308,7 @@ oFFSET_StgAtomicInvariant_code :: Int
 oFFSET_StgAtomicInvariant_code = 0
 #define StgAtomicInvariant_code(__ptr__)  REP_StgAtomicInvariant_code[__ptr__+SIZEOF_StgHeader+OFFSET_StgAtomicInvariant_code]
 oFFSET_StgTRecHeader_enclosing_trec :: Int
-oFFSET_StgTRecHeader_enclosing_trec = 8
+oFFSET_StgTRecHeader_enclosing_trec = 0
 #define StgTRecHeader_enclosing_trec(__ptr__)  REP_StgTRecHeader_enclosing_trec[__ptr__+SIZEOF_StgHeader+OFFSET_StgTRecHeader_enclosing_trec]
 sIZEOF_StgCatchSTMFrame_NoHdr :: Int
 sIZEOF_StgCatchSTMFrame_NoHdr = 16
@@ -362,6 +374,14 @@ oFFSET_StgMVar_tail = 8
 oFFSET_StgMVar_value :: Int
 oFFSET_StgMVar_value = 16
 #define StgMVar_value(__ptr__)  REP_StgMVar_value[__ptr__+SIZEOF_StgHeader+OFFSET_StgMVar_value]
+sIZEOF_StgMVarTSOQueue_NoHdr :: Int
+sIZEOF_StgMVarTSOQueue_NoHdr = 16
+oFFSET_StgMVarTSOQueue_link :: Int
+oFFSET_StgMVarTSOQueue_link = 0
+#define StgMVarTSOQueue_link(__ptr__)  REP_StgMVarTSOQueue_link[__ptr__+SIZEOF_StgHeader+OFFSET_StgMVarTSOQueue_link]
+oFFSET_StgMVarTSOQueue_tso :: Int
+oFFSET_StgMVarTSOQueue_tso = 8
+#define StgMVarTSOQueue_tso(__ptr__)  REP_StgMVarTSOQueue_tso[__ptr__+SIZEOF_StgHeader+OFFSET_StgMVarTSOQueue_tso]
 sIZEOF_StgBCO_NoHdr :: Int
 sIZEOF_StgBCO_NoHdr = 32
 oFFSET_StgBCO_instrs :: Int
@@ -387,6 +407,31 @@ sIZEOF_StgStableName_NoHdr = 8
 oFFSET_StgStableName_sn :: Int
 oFFSET_StgStableName_sn = 0
 #define StgStableName_sn(__ptr__)  REP_StgStableName_sn[__ptr__+SIZEOF_StgHeader+OFFSET_StgStableName_sn]
+sIZEOF_StgBlockingQueue_NoHdr :: Int
+sIZEOF_StgBlockingQueue_NoHdr = 32
+oFFSET_StgBlockingQueue_bh :: Int
+oFFSET_StgBlockingQueue_bh = 8
+#define StgBlockingQueue_bh(__ptr__)  REP_StgBlockingQueue_bh[__ptr__+SIZEOF_StgHeader+OFFSET_StgBlockingQueue_bh]
+oFFSET_StgBlockingQueue_owner :: Int
+oFFSET_StgBlockingQueue_owner = 16
+#define StgBlockingQueue_owner(__ptr__)  REP_StgBlockingQueue_owner[__ptr__+SIZEOF_StgHeader+OFFSET_StgBlockingQueue_owner]
+oFFSET_StgBlockingQueue_queue :: Int
+oFFSET_StgBlockingQueue_queue = 24
+#define StgBlockingQueue_queue(__ptr__)  REP_StgBlockingQueue_queue[__ptr__+SIZEOF_StgHeader+OFFSET_StgBlockingQueue_queue]
+oFFSET_StgBlockingQueue_link :: Int
+oFFSET_StgBlockingQueue_link = 0
+#define StgBlockingQueue_link(__ptr__)  REP_StgBlockingQueue_link[__ptr__+SIZEOF_StgHeader+OFFSET_StgBlockingQueue_link]
+sIZEOF_MessageBlackHole_NoHdr :: Int
+sIZEOF_MessageBlackHole_NoHdr = 24
+oFFSET_MessageBlackHole_link :: Int
+oFFSET_MessageBlackHole_link = 0
+#define MessageBlackHole_link(__ptr__)  REP_MessageBlackHole_link[__ptr__+SIZEOF_StgHeader+OFFSET_MessageBlackHole_link]
+oFFSET_MessageBlackHole_tso :: Int
+oFFSET_MessageBlackHole_tso = 8
+#define MessageBlackHole_tso(__ptr__)  REP_MessageBlackHole_tso[__ptr__+SIZEOF_StgHeader+OFFSET_MessageBlackHole_tso]
+oFFSET_MessageBlackHole_bh :: Int
+oFFSET_MessageBlackHole_bh = 16
+#define MessageBlackHole_bh(__ptr__)  REP_MessageBlackHole_bh[__ptr__+SIZEOF_StgHeader+OFFSET_MessageBlackHole_bh]
 oFFSET_RtsFlags_ProfFlags_showCCSOnException :: Int
 oFFSET_RtsFlags_ProfFlags_showCCSOnException = 224
 #define RtsFlags_ProfFlags_showCCSOnException(__ptr__)  REP_RtsFlags_ProfFlags_showCCSOnException[__ptr__+OFFSET_RtsFlags_ProfFlags_showCCSOnException]
